@@ -88,8 +88,8 @@ template<typename T> struct is_same<T,T> { static const bool value = true; };
 /// Quick test for whether an integer is a power of 2.
 ///
 template<typename T>
-inline OIIO_HOSTDEVICE bool
-ispow2(T x)
+inline OIIO_HOSTDEVICE OIIO_CONSTEXPR14 bool
+ispow2(T x) noexcept
 {
     // Numerous references for this bit trick are on the web.  The
     // principle is that x is a power of 2 <=> x == 1<<b <=> x-1 is
@@ -101,8 +101,8 @@ ispow2(T x)
 
 /// Round up to next higher power of 2 (return x if it's already a power
 /// of 2).
-inline OIIO_HOSTDEVICE int
-pow2roundup(int x)
+inline OIIO_HOSTDEVICE OIIO_CONSTEXPR14 int
+ceil2(int x) noexcept
 {
     // Here's a version with no loops.
     if (x < 0)
@@ -124,8 +124,8 @@ pow2roundup(int x)
 
 /// Round down to next lower power of 2 (return x if it's already a power
 /// of 2).
-inline OIIO_HOSTDEVICE int
-pow2rounddown(int x)
+inline OIIO_HOSTDEVICE OIIO_CONSTEXPR14 int
+floor2(int x) noexcept
 {
     // Make all bits past the first 1 also be 1, i.e. 0001xxxx -> 00011111
     x |= x >> 1;
@@ -139,6 +139,11 @@ pow2rounddown(int x)
 }
 
 
+// Old names -- DEPRECATED(2.1)
+inline OIIO_HOSTDEVICE int pow2roundup(int x) { return ceil2(x); }
+inline OIIO_HOSTDEVICE int pow2rounddown(int x) { return floor2(x); }
+
+
 
 /// Round value up to the next whole multiple.
 /// For example, round_to_multiple(7,10) returns 10.
@@ -209,6 +214,15 @@ rotl64(uint64_t x, int k)
 }
 
 
+
+// safe_mod is like integer a%b, but safely returns 0 when b==0.
+template <class T>
+inline OIIO_HOSTDEVICE T
+safe_mod(T a, T b)
+{
+    return b ? (a % b) : T(0);
+}
+
 // (end of integer helper functions)
 ////////////////////////////////////////////////////////////////////////////
 
